#
# spec file for package lsyncd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           lsyncd
Version:        2.3.1
Release:        2.2
Summary:        Live Syncing (Mirror) Daemon
License:        GPL-2.0-only
Group:          Productivity/Networking/Other
URL:            https://github.com/axkibe/lsyncd
Source0:        https://github.com/axkibe/lsyncd/archive/release-%{version}.tar.gz
Source1:        %{name}.conf
Source2:        rsync_sudo.sh
Source3:        %{name}.service
Source4:        %{name}.sysconfig
Source5:        %{name}.logrotate
BuildRequires:  asciidoc
BuildRequires:  cmake >= 3.5
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(lua) >= 5.2
BuildRequires:  pkgconfig(systemd)
Requires:       logrotate
Requires:       rsync >= 3.1
%{?systemd_requires}

%description
Lsyncd (Live Syncing (Mirror) Daemon) uses rsync to synchronize local directories with a remote machine running rsyncd. It watches multiple directory trees through inotify. The first step after adding the watches is to rsync all directories with the remote host, and then the software synchronizes single files by collecting the inotify events. lsyncd is a lightweight live mirror solution that should be easy to install and use while blending well with your system.

%prep
%autosetup -p1 -n %{name}-release-%{version}

%build
export CFLAGS="%{optflags}"
%cmake \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DCMAKE_INSTALL_MANDIR=%{_mandir}
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}/%{_sbindir} \
   %{buildroot}/%{_sysconfdir}/%{name} \
   %{buildroot}/%{_localstatedir}/log/lsyncd
install -Dm 644 %{SOURCE3} %{buildroot}%{_unitdir}/lsyncd.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
install -Dm 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/logrotate.d/lsyncd
install -Dm 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/lsyncd/lsyncd.conf
install -Dm 755 %{SOURCE2} %{buildroot}%{_sysconfdir}/lsyncd/rsync_sudo.sh
install -Dm 644 %{SOURCE4} %{buildroot}%{_fillupdir}/sysconfig.%{name}
rm -rf %{buildroot}/usr/doc/examples

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc ChangeLog examples/*
%{_bindir}/lsyncd
%{_sbindir}/rc%{name}
%{_mandir}/man1/lsyncd.1%{?ext_man}
%{_unitdir}/lsyncd.service
%config(noreplace) %{_sysconfdir}/logrotate.d/lsyncd
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/lsyncd.conf
%config(noreplace) %{_sysconfdir}/%{name}/rsync_sudo.sh
%dir %{_localstatedir}/log/%{name}
%{_fillupdir}/sysconfig.%{name}

%changelog
* Mon Mar 11 2024 seife+obs@b1-systems.com
- fix tarball to match the source URL
* Tue Mar  5 2024 seife+obs@b1-systems.com
- update to version 2.3.1 (2022-11-17):
  * multiple bugfixes, style fixes
  * add nix flake support
  * add support for tunnel commands
  * add support for batchSizeLimit
  * add -onepass option
  * add crontab support
  * support relative executable paths
- remove obsoleted patches lsyncd-lua.patch, lsyncd-man.patch
- add "After=remote-fs.target" to lsyncd.service to avoid syncing
  unmounted NFS shares
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Wed Oct  6 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * lsyncd.service
* Sun Mar  7 2021 Carsten Ziepke <kieltux@gmail.com>
- Use %%%%cmake macros
* Sun Mar  7 2021 Carsten Ziepke <kieltux@gmail.com>
- Rebase lsyncd-lua.patch and add fix for implicit declaration of
  function lua_objlen - renamed to lua_rawlen in 5.2
- Run spec-cleaner
- Remove insserv configuration and lsyncd-init.d
* Sun Jul 29 2018 jengelh@inai.de
- Replace %%__-type macro indirections. Use %%_smp_mflags for
  parallel build.
* Thu Apr 26 2018 ecsos@opensuse.org
- update to 2.2.3
  - enhaencement: supporting includes with new filter and filterFrom
    options
  - change: needing now at least Lua 5.2 (Lua 5.1 no longer
    supported, Lua5.3 supported)
  - change: if the target/targetdir ends with a ':' do not append
    a trailing '/' to it, since that would change it from homedir
    to rootdir!
  - add: example for Amazon S3 Bucket (Daniel Miranda)
  - fix: setting stdout/stderr to linebuffer mode.
  - fix: Lua5.3 compatiblity, using load() instead of loadstring()
  - fix: cmake lua detection, will resort to "lua" and "luac"
    binaries only if more specific suffixes (e.g. luac5.3) are not
    available
  - fix: test suit, Lua5.3 compatibility (table.unpack)
- changes from 2.2.2
  - fix: checkgauge 'insist'
  - fix: no partial path exlusion tests
  - fix: write pid of forked process in pidfile
  - fix: crash on not reachable target
  - workaround: changed back to filter style rsync calling until
    https://bugzilla.samba.org/show_bug.cgi?id=12569 is fixed and
    released.
- changes from 2.2.1
  - enhancement: now always using filter lists with rysnc instead
    of include/exclude lists taking advantage of the new
  - -delete-missing-args parameter to delete files on target.
    >>> Thus Lsyncd 2.2.1 needs rsync >= 3.1.0
  - change: added "tests" make target to run all the tests.
  - fix: crash due to typo in changed ^path, ^pathdir, ^pathname
- changes from 2.2.0
  - enhancement: add rsync options:
    "append",
    "append_verify",
    "backup",
    "backup_dir",
    "chmod",
    "chown",
    "copy_dirlinks",
    "existing",
    "groupmap",
    "omit_dir_times",
    "omit_link_times",
    "suffix,"
    "usermap",
  - enhancement: settings{ } now checks for unknown entries and
    errors if so.
  - change: Level3 scripts ^path,^pathdir and ^pathname now don't
    start with a slash.
  - change: Lsyncd now writes a startup log message before
    daemonizing does in case logging fails, it is recognized before
    it cannot message anything about it, since it deamonized
  - change: compatible with Lua5.3 (along with 5.1 and 5.2)
  - change: _verbatim forced for 'exitcodes' entry.
  - change: manpage is not rebuild by default. it is provided
    precompiled.
  - change: faulty/deprecated config files that use
    settings = { ... }, with equal sign are no longer worked
    around.
  - change: default.direct now calls copy with -p
  - fix: potential race conditions: default.rsyncssh will now
    channel deletes also through rsync and treats moves as
    blocking events.
  - fix: ']' is not escaped for rsync rules, since rsync only
    applies doesn't applie pattern matching if no other pattern
    chars are found.
  - fix: Shell injection hole close for default.direct on mv
    commands.
  - fix: Crash of default-direct when source doesn't exit
  - fix: fixed faulty event replacement, a race condition noticed
    by extensive default.rsyncssh testing changed Delays were not
    reflected in Events
- changes from 2.1.6
  - enhancement: Lsyncd now locks its pidfile
  - enhancement: added ssh.identifyFile and ssh.options options
  - enhancement: added rsync inplace option
  - fix: ignore blank lines and rsync commenits in exclude files
  - fix: don't tread exclude lines with embedded "+" chars as
    inclusions
  - fix: crash when debugging inotify
  - fix: fixed Finished/Retrying error messages being swapped around
  - fix: properly encapsulate filenames on ssh mv commands to avoid
    shell command injections.
  - fix: postcmd example
  - change: closes also on INT signals
  - change: now removes its pidfile on INT and TERM signals
  - change: changed build system from autotools to cmake
- change url and source to new location
- remove lsyncd-lua-5_3.patch, because no more need
- aad patch lsyncd-lua.patch to find libraries
- add patch lsyncd-man.patch to put manpages to correct location
- fix all rpmlint warnings
- Replace %%__-type macro indirections.
- Use %%_smp_mflags for parallel build.
* Tue Apr 17 2018 mikhail.kasimov@gmail.com
- Updated path to lsyncd.conf for lsyncd.service and lsyncd.sysconfig
  (boo#975118)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Mar 15 2017 dimstar@opensuse.org
- Explicitly package files installed by make install into _docdir:
  rpm 4.13 no longer implicitly packages those files.
* Thu Jul 30 2015 dimstar@opensuse.org
- Add lsyncd-lua-5_3.patch: Fix build with LUA 5.3.
* Fri Jun  5 2015 p.drouand@gmail.com
- Remove scriptlets pre/post on systems with sysvinit support.
* Sun Mar  1 2015 p.drouand@gmail.com
- Update to version 2.1.5
  * enhancement: Added rsync options: bwlimit, timeout
  * fix: Specifying ssh port no longer overwrites the last rsync option
  * fix: rsync option password_file is now accepted
  * fix: onAttrib is accepted again
  * fix: -log Exec now prints now fully all arguments
  * fix: configure script lua detection now includes math lib to workaround
    wrongly created "needs COMPAT_ALL" messages.
  * fix: repaired variable replacement for layer 3 scripts
  * fix: config.delay is now checked to a number >= 0
  * change: a2x is no longer checked by configure script. should not be
    needed when building from tarball
- Use download Url as source
- Add sysconfig config script support for init scripts
- Fix sysvinit script to be able to use sysconfig options
- Add systemd support for openSUSE > 13.2
- Add required macros to support correctly sysvinit script
- Remove redundant %%clean section
* Wed Feb  6 2013 e.istomin@edss.ee
- update to 2.1.4
- remove lua 5.2 patch (https://github.com/axkibe/lsyncd/pull/148)
* Tue Oct  9 2012 crrodriguez@opensuse.org
- Build against LUA 5.2
* Sun Feb 26 2012 dmueller@suse.de
- fix build in factory (build against lua 5.1)
* Mon Nov 28 2011 eugene.istomin@edss.ee
- update to 2.0.5
  * fix: Lsyncd will now terminate if it inotify watching exceeds
    its preset limit.
  * fix: rsync error exit code 12 now results in retries.
  * fix: Lsyncd 2.0.5 should now compile better on a bit elder
    GNU/Linux versions.
  * fix: examples are now installed in the configured document directory.
  * fix: partial transfers during startup are considered ok. Lsyncd
    will rework the specified files anyway.
  * change: Layer 1 interface init() now receives an "Init" event
    instead of an inlet.
  * change: builtin Lua code is now loaded via a c-array.Now more
    portable and correct memory flags are set.
  * change: Lsyncd will now bail on unknown error codes.
  * enhancement: settings.maxProcesses can now be set as a global limit of childprocesses
  * enhancement: Lsyncd will refuse to start when any startup rsync
    does not work cleanly and returns "again" unless settings.insist or
  - -insist is specified, then Lsyncd will keep retrying until it works.
  * enhancement: option "rsyncBinary" determines which rsync Lsyncd calls.
    Default is "/usr/bin/rsync"
  * enhancement: fsevents ("inotify for OSX") fixed for Snowleopard.
    and is available to configure by default.
  * enhancement: settings.inotifyMode: the actualy Modification event
    Lsyncd reacts to can now be configured. Default is to react on
    file closing in write mode.
  * enhancement: readdir(path) is available to userscripts, reads the contents
    of a directory.
* Mon Mar 28 2011 dmacvicar@suse.de
- update to 2.0.4
  * enhancement: new setting options logident, logfacility
  * fix: moving filenames with spaces through ssh
  * fix: excludes containing chars %% $ ( ) . [ ] + -
  * fix: various typos
  * change: api, settings.statusInterval instead of
  settings.statusIntervall
* Tue Mar  8 2011 dmacvicar@suse.de
- update to 2.0.3
  * enhancement: new default target --direct using /bin/ binaries
    to keep to local dirs in sync (and by default
    not preserving ownership)
  * example: added a new example how to remotely execute a command
    after each rsync operations
  * fix: possible crash with long rsyncOps table exceeding lua stack.
  * fix: excludes now properly match relative and absolute paths
  * fix: call to nil function when manually adding blanket delays
  * fix: on ReiserFS not delivering proper dir stats and when
    encountering a symlink, aquire the node stat for the symlink
    instead from the linked node.
  * change: leave lua apichecking enabled by default.
* Fri Jan 21 2011 dmacvicar@suse.de
- update to 2.0.2
  * fix: exclude rules not terminated with '/' now match a file or dir
  named exactly the same not starting with.
  * fix: pass exclude rules to the startup sync
  * fix: when matching exclusion to not add inotify use same partial path
    than on syncs
  * fix: properly close pipes that needed more than one write.
- 2.0.1 changes
  * most important fix: The garbage collector in 2.0.0 was able to
    remove event lists just at the wrong moment so an "agent unknown"
    error was raised.
  * fixed: The pid in the pidfile should be now the pid after the deamon
    fork() and not the pid initiators pid.
  * improved: You can now specify multiple command-line options in
    rsyncOps by using a table. eg. rsyncOps = {"--lts", "--safe-links"}
* Thu Dec  2 2010 dmacvicar@suse.de
- update to 2.0.0 final
* Fri Nov 26 2010 dmacvicar@suse.de
- update to 2.0beta3
